==> polemarch-2.0.0b1.tar.gz: polemarch-2.0.0b1/polemarch/translations/ru.py <==
# flake8: noqa: E501
TRANSLATION = {
    'User settings were successfully saved.': 'Пользовательские настройки были успешно сохранены.',

    # field titles and names
    'project id': 'id проекта',
    'Contains groups': 'Содержит группы',
    'Start time': 'Время начала',
    'Executor': 'Исполнитель',
    'Initiator': 'Инициатор',
    'Project': 'Проект',
    'Inventory': 'Инвенторий',
    'Stop time': 'Время окончания',
    'Revision': 'Ревизия',
    'Execute args': 'Аргументы запуска',
    'Execution time': 'Время выполнения',
    'stdout': 'вывод из консоли',
    'Raw args': 'Исходные аргументы',
    'Raw stdout': 'Сырой вывод из консоли',
    'Full raw stdout': 'Полный сырой вывод из консоли',
    'Raw inventory': 'Текстовый инвенторий',
    'When': 'Когда',
    'enable': 'доступный',
    'Recipients': 'Получатели',
    'inventory id': 'id инвентория',
    'inventory file': 'файл инвентория',
    'repo type': 'тип репозитория',
    'repo url': 'url репозитория',
    'repo auth type': 'тип авторизации в репозитории',
    'repo auth data': 'данные авторизации в репозитории',
    'branch for git(branch/tag/sha) or tar(subdir)': 'ветка для git(branch/tag/sha) или tar(subdir)',
    'branch': 'ветка',
    'Module': 'Модуль',
    'Group': 'Группа',
    'history id': 'id записи в истории',
    'Playbook': 'Плейбук',
    'tags': 'тэги',
    'task type': 'тип задачи',
    'Save result': 'Сохранять результат',
    'template': 'шаблон',
    'template opt': 'опция шаблона',
    'enabled': 'доступен',
    'interval type': 'типа интервала',
    'schedule': 'расписание',
    'options_list': 'список опций',
    'arguments': 'аргументы',
    'option': 'опция',
    'active': 'активен',
    'all_tasks': 'все задачи',
    'delay': 'отложено',
    'interrupted': 'прервано',
    'offline': 'оффлайн',
    'collapse': 'свернуть',
    'sort': 'порядок сортировки',
    'pmwuserscounter': 'счетчик пользователей',
    'pmwprojectscounter': 'счетчик проектов',
    'pmwtemplatescounter': 'счетчик шаблонов',
    'pmwinventoriescounter': 'счетчик инвенториев',
    'pmwgroupscounter': 'счетчик групп',
    'pmwhostscounter': 'счетчик хостов',
    'pmwchartwidget': 'график',
    'Copy': 'Скопировать',
    'Execute module': 'Запустить модуль',
    'Execute playbook': 'Запустить плейбук',
    'Set owner': 'Установить владельца',
    'Community template': 'Шаблон от сообщества',
    'Use it': 'Использовать',
    'Variables': 'Переменные',
    'Host': 'Хост',
    'History': 'История',
    'Clear': 'Очистить',
    'Facts': 'Факты',
    'Hook': 'Хук',
    'Import inventory': 'Импортировать инвенторий',
    'File import inventory': 'Импортировать инвенторий из файла',
    'All groups': 'Все группы',
    'All hosts': 'Все хосты',
    'Periodic task': 'Периодическая задача',
    'Execute': 'Выполнить',
    'Sync': 'Синхронизировать',
    'Team': 'Команда',
    'Template option': 'Опция шаблона',
    'Hosts': 'Хосты',
    'Execution templates': 'Шаблоны запуска',
    'Info': 'Информация',
    'Information': 'Информация',
    'Notes': 'Заметки',
    'Name': 'Имя',
    'Repository': 'Репозиторий',
    'Status': 'Статус',
    'Branch': 'Ветка',
    'Owner': 'Владелец',
    'Type': 'Тип',
    'Kind': 'Тип',
    'Option': 'Опция',
    'Schedule': 'Расписание',
    'Execute parameters': 'Параметры выполнения',

    'Quick playbook execution form': 'Форма быстрого запуска плейбуков',
    'execute parameters': 'параметры запуска',
    'additional execute parameters': 'дополнительные параметры запуска',
    'Execution output': 'Результаты запуска',

    'Period': 'Период',
    'last 3 years': 'последние 3 года',
    'last year': 'последний год',
    'last 3 months': 'последние 3 месяца',
    'last month': 'последний месяц',
    'last 2 weeks': 'последние 2 недели',
    'last week': 'последняя неделя',
    'last 3 days': 'последние 3 дня',

    'Statistic': 'Cтатистика',
    'Tasks history': 'История запуска задач',
    'Dashboard': 'Дашборд',

    'all_tasks - active': 'все задачи - активна',
    'delay - active': 'отложено - активна',
    'ok - active': 'ok - активна',
    'error - active': 'ошибка - активна',
    'interrupted - active': 'прервано - активна',
    'offline - active': 'оффлайн - активна',

    'templates': 'шаблоны',
    'projects': 'проекты',
    'inventories': 'инвентории',
    'groups': 'группы',
    'hosts': 'хосты',
    'users': 'пользователи',
    'hooks': 'хуки',
    'system': 'система',
    'community': 'сообщество',

    'templates counter': 'шаблонов | шаблон | шаблона | шаблонов',
    'projects counter': 'проектов | проект | проекта | проектов',
    'inventories counter': 'инвенториев | инвенторий | инвентория | инвенториев',
    'groups counter': 'групп | группа | группы | групп',
    'hosts counter': 'хостов | хост | хоста | хостов',
    'users counter': 'пользователей | пользователь | пользователя | пользователей',

    # pmCustomizer
    'history status ok': 'история - статус ok',
    'history status error': 'история - статус ошибка',
    'history status interrupted': 'история - статус прервано',
    'history status delay': 'история - статус отложено',
    'history status offline': 'история - статус оффлайн',
    'history status run': 'история - статус запущено',
    'project status new': 'проект - статус new',
    'project status error': 'проект - статус error',
    'project status ok': 'проект - статус ok',
    'project status wait_sync': 'проект - статус wait_sync',
    'project status sync': 'проект - статус sync',
    'chart legend text color': 'тест легенды графика на дашборде',
    'chart axes text color': 'тект обозначений на линиях графика на дашборд',
    'chart axes lines color': 'цвет линий графика на дашборд',

    # filters
    'path': 'путь',
    'older': 'старше',
    'newer': 'новее',
    'path__not': 'путь не равный',
    'playbook__not': 'плейбук не равный',

    # filters description
    'list of variables to filter. comma separeted "key:value" list.': 'список переменных для фильтрации. последовательность "ключ:значение" разделенная запятой.',
    'a key name string value (or comma separated list) of instance.': 'ключевое имя объекта (или их последовательность разделенная запятой).',
    'a value of instance.': 'значение объекта.',
    'instance type.': 'тип объекта.',
    'module or playbook name.': 'имя модуля или плейбука',
    'kind of execution.': 'тип запуска.',
    'status of execution.': 'статус запуска.',
    'older then this time': 'раньше, чем это время',
    'newer then this time': 'позже, чем это время',
    'project sync status.': 'статус синхронизации проекта.',
    'full path to module.': 'полный путь к модулю.',
    'name of module.': 'имя модуля.',
    'periodic task module or playbook name.': 'имя модуля или плейбука, используемого в переодической задаче.',
    'kind of periodic task.': 'тип переодической задачи.',
    'a unique integer id of template used in periodic task.': 'уникальный числовой id шаблона, используемого в переодической задаче.',
    'playbook filename.': 'имя файла плейбука.',
    'a kind of template.': 'тип шаблона.',
    'the inventory id or path in project.': 'id инвентория или путь в проекте.',

    # fields description
    'application interface language': 'язык интерфейса приложения',
    'application automatically updates pages data with following interval (time in seconds)': 'приложение будет автоматически обновлять данные на страницах с указанным интервалом (время в секундах)',
}

==> polemarch-2.1.1.tar.gz: polemarch-2.1.1/polemarch/translations/ru.py <==
# flake8: noqa: E501
TRANSLATION = {
    'User settings were successfully saved.': 'Пользовательские настройки были успешно сохранены.',
    'Invalid path. Path must not contain "..", "~" or any other special characters and must be relative.':
        'Неправильный путь. Путь не должен содержать "..", "~" и другие специальные символы, а также должен быть относительным.',

    # field titles and names
    'project id': 'id проекта',
    'Start time': 'Время начала',
    'Executor': 'Исполнитель',
    'Initiator': 'Инициатор',
    'Project': 'Проект',
    'Inventory': 'Инвенторий',
    'Stop time': 'Время окончания',
    'Revision': 'Ревизия',
    'Execute args': 'Аргументы запуска',
    'Execution time': 'Время выполнения',
    'stdout': 'вывод из консоли',
    'Raw args': 'Исходные аргументы',
    'Raw stdout': 'Сырой вывод из консоли',
    'Full raw stdout': 'Полный сырой вывод из консоли',
    'Raw inventory': 'Текстовый инвенторий',
    'When': 'Когда',
    'Description': 'Описание',
    'enable': 'доступный',
    'Recipients': 'Получатели',
    'inventory id': 'Id инвентория',
    'inventory file': 'Файл инвентория',
    'branch': 'ветка',
    'Module': 'Модуль',
    'Group': 'Группа',
    'history id': 'id записи в истории',
    'Playbook': 'Плейбук',
    'tags': 'тэги',
    'Type': 'Тип',
    'Save result': 'Сохранять результат',
    'Template': 'Шаблон',
    'Template opt': 'Опция шаблона',
    'Enabled': 'Доступен',

    'General': 'Общее',
    'New owner': 'Новый владелец',
    'Project based': 'Основан на проекте',
    'Repo type': 'Тип репозитория',
    'Repo url': 'URL репозитория',
    'Auth data': 'Данные авторизации',
    'Repo auth type': 'Тип авторизации в репозитории',
    'Repo auth data': 'Данные авторизации в репозитории',
    'Branch for GIT (branch/tag/SHA) or TAR (subdir)': 'Ветка для GIT (branch/tag/SHA) или TAR (поддиректория)',
    'Directory with playbooks': 'Каталог с плейбуками',
    'Information': 'Информация',
    'Arguments': 'Аргументы',
    'Task type': 'Тип задачи',
    'Interval type': 'Типа интервала',
    'Contains groups': 'Содержит группы',
    'Mode': 'Режим',
    'schedule': 'расписание',
    'options_list': 'список опций',
    'option': 'опция',
    'active': 'активен',
    'all_tasks': 'все задачи',
    'delay': 'отложено',
    'interrupted': 'прервано',
    'offline': 'оффлайн',
    'collapse': 'свернуть',
    'sort': 'порядок сортировки',
    'pmwuserscounter': 'счетчик пользователей',
    'pmwprojectscounter': 'счетчик проектов',
    'pmwtemplatescounter': 'счетчик шаблонов',
    'pmwinventoriescounter': 'счетчик инвенториев',
    'pmwgroupscounter': 'счетчик групп',
    'pmwhostscounter': 'счетчик хостов',
    'pmwchartwidget': 'график',
    'Copy': 'Скопировать',
    'Execute module': 'Запустить модуль',
    'Execute playbook': 'Запустить плейбук',
    'Set owner': 'Установить владельца',
    'Community template': 'Шаблон от сообщества',
    'Use it': 'Использовать',
    'Variables': 'Переменные',
    'Host': 'Хост',
    'History': 'История',
    'Clear': 'Очистить',
    'Facts': 'Факты',
    'Hook': 'Хук',
    'Import inventory': 'Импортировать инвенторий',
    'File import inventory': 'Импортировать инвенторий из файла',
    'All groups': 'Все группы',
    'All hosts': 'Все хосты',
    'Periodic task': 'Периодическая задача',
    'Execute': 'Выполнить',
    'Sync': 'Синхронизировать',
    'Team': 'Команда',
    'Template option': 'Опция шаблона',
    'Hosts': 'Хосты',
    'Execution templates': 'Шаблоны запуска',
    'Info': 'Информация',
    'Notes': 'Заметки',
    'Name': 'Имя',
    'Repository': 'Репозиторий',
    'Status': 'Статус',
    'Options': 'Опции',
    'Branch': 'Ветка',
    'Owner': 'Владелец',

    'Kind': 'Вид',
    'Option': 'Опция',
    'Schedule': 'Расписание',
    'Execute parameters': 'Параметры выполнения',
    'Id not': 'Id не',
    'Name not': 'Имя не',
    'Status not': 'Статус не',
    'Key': 'Ключ',
    'Value': 'Значение',
    'Add': 'Добавить',
    'Raw data': 'Исходные данные',
    'Children': 'Вложенные группы',
    'Inventory path': 'Путь к инвенторию',
    'Hosts list': 'Список хостов',
    'Quick playbook execution form': 'Форма быстрого запуска плейбуков',
    'execute parameters': 'параметры запуска',
    'additional execute parameters': 'дополнительные параметры запуска',
    'Execution output': 'Результаты запуска',

    'Period': 'Период',
    'last 3 years': 'последние 3 года',
    'last year': 'последний год',
    'last 3 months': 'последние 3 месяца',
    'last month': 'последний месяц',
    'last 2 weeks': 'последние 2 недели',
    'last week': 'последняя неделя',
    'last 3 days': 'последние 3 дня',

    'Statistics': 'Статистика',
    'Tasks history': 'История запуска задач',
    'Dashboard': 'Дашборд',

    'all_tasks - active': 'все задачи - активна',
    'delay - active': 'отложено - активна',
    'ok - active': 'ok - активна',
    'error - active': 'ошибка - активна',
    'interrupted - active': 'прервано - активна',
    'offline - active': 'оффлайн - активна',

    'templates': 'шаблоны',
    'projects': 'проекты',
    'inventories': 'инвентории',
    'Groups': 'Группы',
    'hosts': 'хосты',
    'users': 'пользователи',
    'hooks': 'хуки',
    'system': 'система',
    'community': 'сообщество',
    'User': 'Пользователь',

    'templates counter': 'шаблонов | шаблон | шаблона | шаблонов',
    'projects counter': 'проектов | проект | проекта | проектов',
    'inventories counter': 'инвенториев | инвенторий | инвентория | инвенториев',
    'groups counter': 'групп | группа | группы | групп',
    'hosts counter': 'хостов | хост | хоста | хостов',
    'users counter': 'пользователей | пользователь | пользователя | пользователей',

    # pmCustomizer
    'history status ok': 'история - статус ok',
    'history status error': 'история - статус ошибка',
    'history status interrupted': 'история - статус прервано',
    'history status delay': 'история - статус отложено',
    'history status offline': 'история - статус оффлайн',
    'history status run': 'история - статус запущено',
    'project status new': 'проект - статус new',
    'project status error': 'проект - статус error',
    'project status ok': 'проект - статус ok',
    'project status wait_sync': 'проект - статус wait_sync',
    'project status sync': 'проект - статус sync',
    'chart legend text color': 'тест легенды графика на дашборде',
    'chart axes text color': 'текст обозначений на линиях графика на дашборд',
    'chart axes lines color': 'цвет линий графика на дашборд',

    # filters
    'Path': 'Путь',
    'Older': 'Старше',
    'Newer': 'Новее',
    'Path__not': 'Путь не равный',
    'Path not': 'Путь не равный',
    'Playbook__not': 'Плейбук не равный',
    'Playbook not': 'Плейбук не равный',
    'Pb filter': 'Фильтр плейбуков',

    # fields description
    'application interface language': 'язык интерфейса приложения',
    'application automatically updates pages data with following interval (time in seconds)': 'приложение будет автоматически обновлять данные на страницах с указанным интервалом (время в секундах)',
    'List of variables to filter. Comma separated "key:value" list.': 'Список переменных для фильтрации. Последовательность "ключ:значение", разделенная запятой.',
}

SERVER_TRANSLATION = {
    # filters description
    'A key name string value (or comma separated list) of instance.': 'Ключевое имя объекта (или их последовательность, разделенная запятой).',
    'A value of instance.': 'Значение объекта.',
    'Instance type.': 'Тип объекта.',
    'A kind of template.': 'Вид шаблона.',
    'The inventory id or path in project.': 'Id инвентория или путь в проекте.',
    'Full path to module.': 'Полный путь к модулю.',
    'Name of module.': 'Название модуля.',
    'Project sync status.': 'Статус синхронизации проекта.',
    'Playbook filename.': 'Имя файла плейбука.',
    'Playbook filename - filter for prefetch.': 'Имя файла плейбука — фильтр предварительной выборки.',
    'Module or playbook name.': 'Название модуля или плейбука.',
    'Kind of execution.': 'Тип запуска.',
    'Status of execution.': 'Статус запуска.',
    'Older then this time': 'Раньше, чем это время',
    'Newer then this time': 'Позже, чем это время',
    'Periodic task module or playbook name.': 'Название модуля или плейбука, используемого в периодической задаче.',
    'Kind of periodic task.': 'Вид периодической задачи.',
    'A unique integer id of template used in periodic task.': 'Уникальный числовой Id шаблона, используемого в периодической задаче.',
}
